  /* --------------------------------------------------------------- */
  /* sample.c -- Tollos sample application                           */
  /*                                                                 */
  /* For detailed explanation of this, see:                          */
  /*                                                                 */
  /*   http://speleotrove.com/tollos/Sample_application.html         */
  /*                                                                 */
  /* --------------------------------------------------------------- */

  #include "tollos.h"           // Tollos library

  /* --------------------------------------------------------------- */
  /* init -- initialization function                                 */
  /*                                                                 */
  /* This is called once, after C and processor initialization.      */
  /* Return 0 to start tick() calls, or 1 to halt (power down).      */
  /* --------------------------------------------------------------- */
  int init(void) {

    // Send a string to the host computer terminal
    debugf("%s; sample compiled on %s at %s\n", TOLLOS_VERSION,
           __DATE__, __TIME__);

    // blink LED4 (if any) for a second
    ledSet(4, LED_INVERT);
    sysPause(1000);             // wait 1000 ms
    ledSet(4, LED_INVERT);

    // Request that the watchdog timer reset the processor if a
    // tick() call takes more than 2 seconds
    sysSet(SYS_WATCHDOG, 2000);

    return 0;
    } // init


  /* --------------------------------------------------------------- */
  /* tick -- repeating tick function                                 */
  /*                                                                 */
  /* This is called once a tick (default 25 Hz) after init() ends.   */
  /* Return 0 to continue tick() calls, or 1 to halt (power down).   */
  /* --------------------------------------------------------------- */
  int tick(void) {
    static int ticks=0;         // counter
    int c;                      // work

    // Change a LED state every second
    ticks++;                    // bump counter
    if (ticks==25) {            // every second ..
      ledSet(1, LED_INVERT);    // .. invert LED1
      ticks=0;                  // .. and reset counter
      }

    // Flip Port 1 bit 31 every tick [to watch on a 'scope]
    // On the mbed this is pin 20
    bitSet(PORT1, BIT31, BIT_INVERT);

    // check the serial input
    c=debugGet();
    if       (c=='1') ledSet(1, LED_INVERT);
     else if (c=='2') ledSet(2, LED_INVERT);
     else if (c=='3') ledSet(3, LED_INVERT);
     else if (c=='4') ledSet(4, LED_INVERT);
     else if (c=='x') return 1;                     // power off
     else if (c=='?') {                             // do some queries
      debugf("SysTickTime   %d\n", sysQuery(SYS_TICKTIME));
      debugf("SysTickMax    %d\n", sysQuery(SYS_TICKMAX));
      debugf("SysStackUsed  %d\n", sysQuery(SYS_STACKUSED));
      debugf("SysWatchdog   %d\n", sysQuery(SYS_WATCHDOG));
      }
     // other characters (and -1) are ignored

    return 0;
    } // tick

